@@ -1,7 +1,7 @@
 from __future__ import print_function
 
 __author__ = 'Lei Xu <eddyxu@gmail.com>'
-__version__ = '0.0.6'
+__version__ = '0.0.7'
 
 __classifiers__ = [
     'Development Status :: 2 - Pre-Alpha',
@@ -46,6 +46,8 @@ def run():
                         help='set the root directory')
     parser.add_argument('-e', '--exclude', metavar='DIR|FILE', action='append',
                         help='set exclude file or directory')
+    parser.add_argument('-x', '--extension', metavar='EXT', action='append',
+                        help='set extension of files to process')
     parser.add_argument('-y', '--coveralls-yaml', default='.coveralls.yml',
                         metavar='FILE',
                         help='coveralls yaml file name '
