@@ -6,9 +6,15 @@ import re
 from coveralls import gitrepo
 
 
-def is_source_file(filepath):
+_CPP_EXTENSIONS = ['.h', '.hpp', '.cpp', '.cc', 'c']
+
+
+def is_source_file(args, filepath):
     """Returns true if it is a C++ source file."""
-    return os.path.splitext(filepath)[1] in ['.h', '.hpp', '.cpp', '.cc', '.c']
+    if args.extension:
+        return os.path.splitext(filepath)[1] in args.extension
+    else:
+        return os.path.splitext(filepath)[1] in _CPP_EXTENSIONS
 
 
 def exclude_paths(args):
@@ -20,15 +26,20 @@ def exclude_paths(args):
     return results
 
 
-def is_under_exclude_path(args, filepath):
+def is_excluded_path(args, filepath):
     """Returns true if the filepath is under the one of the exclude path
     """
     excl_paths = exclude_paths(args)
     abspath = os.path.abspath(filepath)
     for excluded_path in excl_paths:
-        relpath = os.path.relpath(abspath, excluded_path)
-        if len(relpath) > 3 and relpath[:3] != '../':
-            return True
+        if os.path.isdir(excluded_path):
+            relpath = os.path.relpath(abspath, excluded_path)
+            if len(relpath) > 3 and relpath[:3] != '../':
+                return True
+        else:
+            absexcludefile = os.path.abspath(excluded_path)
+            if absexcludefile == abspath:
+                return True
     return False
 
 
@@ -87,7 +98,7 @@ def collect(args):
                     src_path = os.path.relpath(source_file_path, abs_root)
                     if len(src_path) > 3 and src_path[:3] == '../':
                         continue
-                    if is_under_exclude_path(args, source_file_path):
+                    if is_excluded_path(args, source_file_path):
                         continue
 
                     src_report = {}
@@ -132,7 +143,9 @@ def collect(args):
         dirs[:] = filtered_dirs
 
         for filename in files:
-            if not is_source_file(filename):
+            if not is_source_file(args, filename):
+                continue
+            if is_excluded_path(args, filename):
                 continue
             filepath = os.path.relpath(os.path.join(root, filename), abs_root)
             if not filepath in discoverd_files:
